==> gtnh_customizer-v0.9.0-sources.jar: com/glektarssza/gtnh_customizer/mixins/LateMixinInitializer.java <==
package com.glektarssza.gtnh_customizer.mixins;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import com.gtnewhorizon.gtnhmixins.ILateMixinLoader;
import com.gtnewhorizon.gtnhmixins.LateMixin;

import cpw.mods.fml.common.FMLCommonHandler;
import cpw.mods.fml.relauncher.Side;

/**
 * The late-stage mixin initializer.
 */
@LateMixin
public class LateMixinInitializer implements ILateMixinLoader {

    @Override
    public String getMixinConfig() {
        return "mixins.gtnh_customizer.late.json";
    }

    @Override
    public List<String> getMixins(Set<String> loadedMods) {
        List<String> mixins = new ArrayList<String>();
        if (loadedMods.contains("SpecialMobs")) {
            mixins.add("specialmobs.Entity_SpecialGhastMixin");
            mixins.add("specialmobs.Entity_SpecialCaveSpiderMixin");
            mixins.add("specialmobs.Entity_SpecialSpiderMixin");
            mixins.add("specialmobs.EntityEnderCreeperMixin");
        }
        if (loadedMods.contains("Thaumcraft")) {
            mixins.add("thaumcraft.EntityWispMixin");
        }
        if (loadedMods.contains("XaeroMinimap")
            && FMLCommonHandler.instance().getEffectiveSide() == Side.CLIENT) {
            mixins.add("xaeros.client.WaypointsManagerMixins");
        }
        if (loadedMods.contains("TConstruct")) {
            mixins.add("tconstruct.SlimeSaplingMixin");
        }
        if (loadedMods.contains("serverutilities")) {
            mixins.add("serverutilities.MessageEditNBTRequestMixin");
        }
        return mixins;
    }
}

==> gtnh_customizer-v0.11.0-sources.jar: com/glektarssza/gtnh_customizer/mixins/LateMixinInitializer.java <==
package com.glektarssza.gtnh_customizer.mixins;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import com.gtnewhorizon.gtnhmixins.ILateMixinLoader;
import com.gtnewhorizon.gtnhmixins.LateMixin;

import cpw.mods.fml.common.FMLCommonHandler;
import cpw.mods.fml.relauncher.Side;

/**
 * The late-stage mixin initializer.
 */
@LateMixin
public class LateMixinInitializer implements ILateMixinLoader {
    /**
     * Get the name of the mixin config file.
     *
     * @returns The name of the mixin config file.
     */
    @Override
    public String getMixinConfig() {
        return "mixins.gtnh_customizer.late.json";
    }

    /**
     * Get the list of additional mixins to load based on the loaded mods.
     *
     * @param loadedMods - The list of mods current loaded.
     *
     * @returns The list of additional mixins to load based on the loaded mods.
     */
    @Override
    public List<String> getMixins(Set<String> loadedMods) {
        List<String> mixins = new ArrayList<String>();
        if (loadedMods.contains("SpecialMobs")) {
            mixins.add("specialmobs.Entity_SpecialGhastMixin");
            mixins.add("specialmobs.Entity_SpecialCaveSpiderMixin");
            mixins.add("specialmobs.Entity_SpecialSpiderMixin");
            mixins.add("specialmobs.EntityEnderCreeperMixin");
        }
        if (loadedMods.contains("Thaumcraft")) {
            mixins.add("thaumcraft.EntityWispMixin");
        }
        if (loadedMods.contains("XaeroMinimap")
            && FMLCommonHandler.instance().getEffectiveSide() == Side.CLIENT) {
            mixins.add("xaeros.client.WaypointsManagerMixins");
        }
        if (loadedMods.contains("TConstruct")) {
            mixins.add("tconstruct.SlimeSaplingMixin");
        }
        if (loadedMods.contains("serverutilities")) {
            mixins.add("serverutilities.MessageEditNBTRequestMixin");
            mixins.add("serverutilities.GuiEditNBTMixin");
            mixins.add("serverutilities.TextBoxMixin");
        }
        return mixins;
    }
}
